@@ -4,9 +4,9 @@ use warnings;
 package Util::H2O::More;
 use parent q/Exporter/;
 
-our $VERSION = q{0.2.8};
+our $VERSION = q{0.2.9};
 
-our @EXPORT_OK = (qw/baptise opt2h2o h2o o2h d2o o2d o2h2o ini2h2o h2o2ini Getopt2h2o/);
+our @EXPORT_OK = (qw/baptise opt2h2o h2o o2h d2o o2d o2h2o ini2h2o h2o2ini Getopt2h2o ddd dddie/);
 
 use Util::H2O ();
 
@@ -59,7 +59,7 @@ sub baptise ($$@) {
 # preconditioner for use with Getopt::Long flags; returns just the flag name given
 # a list of option descriptors, e.g., qw/option1=s option2=i option3/;
 
-# Getopts to keys
+# Getopt to keys
 sub opt2h2o(@) {
     my @getopt_def = @_;
     my @flags_only = map { m/([^=|\s]+)/g; $1 } @getopt_def;
@@ -205,6 +205,23 @@ sub o2d($) {
     return Util::H2O::o2h $thing;
 }
 
+# handy, poor man's debug wrappers
+
+sub ddd(@) {
+    require Data::Dumper;
+    foreach my $ref (@_) {
+        print STDERR Data::Dumper::Dumper($ref);
+    }
+}
+
+sub dddie(@) {
+    require Data::Dumper;
+    foreach my $ref (@_) {
+        print STDERR Data::Dumper::Dumper($ref);
+    }
+    die qq{died due to use of dddie};
+}
+
 1;
 
 __END__
@@ -352,7 +369,7 @@ C<baptise> and C<bastise -recurse>.
 =head2 C<Getopt2h2o REF, REF, LIST>
 
 Wrapper around the idiom enabled buy C<opt2h2o>. It even will C<require>
-C<Getopts::Long>. Usage:
+C<Getopt::Long>. Usage:
 
   use Util::H2O::More qw/Getopt2h2o/;
   my $opts_ref = Getopt2h2o \@ARGV, { n => 10 }, qw/f=s n=i/;
@@ -630,6 +647,20 @@ convenient that doing,
 
   my $count = scalar @{$root->some->barray->all}; 
 
+=head2 Debugging Methods
+
+=head3 C<ddd LIST>
+
+Takes a list and applies L<Data::Dumper>'s C<::Dumper> method to them, in turn. Prints to
+C<STDERR>.
+
+Used for debugging data structures, which is a likely thing to need if using this module.
+
+L<Data::Dumper> is C<require>'d by this method.
+
+=head3 C<dddie LIST>
+
+Does the same thing as C<ddd>, but C<die>s at the end.
 
 =head1 EXTERNAL METHODS
 
